<?php
/**
 * Helper functions for the admin - plugin links.
 *
 * @package    WooCommerce German (de_DE)
 * @subpackage Admin
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright 2012, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link       http://genesisthemes.de/en/wp-plugins/woocommerce-de/
 * @link       http://twitter.com/#!/deckerweb
 *
 * @since 1.0
 * @version 1.1
 */

/**
 * Setting internal plugin helper links constants
 *
 * @since 2.2
 */
define( 'WCBR_URL_TRANSLATE',		'http://translate.wpautobahn.com/projects/wordpress-plugins-deckerweb/woocommerce-de' );
define( 'WCBR_URL_WPORG_FAQ',		'http://wordpress.org/extend/plugins/woocommerce-de/faq/' );
define( 'WCBR_URL_WPORG_FORUM',		'http://wordpress.org/support/plugin/woocommerce-de' );
define( 'WCBR_URL_WPORG_PROFILE',	'http://profiles.wordpress.org/daveshine/' );
if ( get_locale() == 'pt_BR' ){
	define( 'WCBR_URL_DONATE', 	'http://genesisthemes.de/spenden/' );
	define( 'WCBR_URL_PLUGIN',	'http://genesisthemes.de/plugins/woocommerce-de/' );
	define( 'WCBR_IS_BRAZILIAN', 	true );
} else {
	define( 'WCBR_URL_DONATE', 	'http://genesisthemes.de/en/donate/' );
	define( 'WCBR_URL_PLUGIN',	'http://genesisthemes.de/en/wp-plugins/woocommerce-de/' );
	define( 'WCBR_IS_BRAZILIAN', 	false );
}


/**
 * Add "Settings" link to plugin page
 *
 * @since 2.0
 *
 * @param  $wcbr_links
 * @param  $wcbr_settings_link
 * @return strings settings link
 */
function ddw_wcbr_settings_page_link( $wcbr_links ) {

	$wcbr_settings_link = sprintf( '<a href="%s" title="%s">%s</a>' , admin_url( 'admin.php?page=woocommerce' ) , __( 'Go to the WooCommerce settings page', 'woocommerce-pt_BR' ) , __( 'WooCommerce Settings', 'woocommerce-pt_BR' ) );
	
	array_unshift( $wcbr_links, $wcbr_settings_link );

	return $wcbr_links;

}  // end of function ddw_wcbr_settings_page_link


add_filter( 'plugin_row_meta', 'ddw_wcbr_plugin_links', 10, 2 );
/**
 * Add various support links to plugin page
 *
 * @since 1.0
 */
function ddw_wcbr_plugin_links( $wcbr_links, $wcbr_file ) {

	if ( ! current_user_can( 'install_plugins' ) )
		return $wcbr_links;

	if ( $wcbr_file == WCBR_PLUGIN_BASEDIR . '/woocommerce-br.php' ) {
		$wcbr_links[] = '<a href="' . esc_url_raw( WCBR_URL_WPORG_FAQ ) . '" target="_new" title="' . __( 'FAQ', 'woocommerce-pt_BR' ) . '">' . __( 'FAQ', 'woocommerce-pt_BR' ) . '</a>';
		$wcbr_links[] = '<a href="' . esc_url_raw( WCBR_URL_WPORG_FORUM ) . '" target="_new" title="' . __( 'Support', 'woocommerce-pt_BR' ) . '">' . __( 'Support', 'woocommerce-pt_BR' ) . '</a>';
		$wcbr_links[] = '<a href="' . esc_url_raw( WCBR_URL_TRANSLATE ) . '" target="_new" title="' . __( 'Translations', 'woocommerce-pt_BR' ) . '">' . __( 'Translations', 'woocommerce-pt_BR' ) . '</a>';
		$wcbr_links[] = '<a href="' . esc_url_raw( WCBR_URL_DONATE ) . '" target="_new" title="' . __( 'Donate', 'woocommerce-pt_BR' ) . '">' . __( 'Donate', 'woocommerce-pt_BR' ) . '</a>';
	}

	return $wcbr_links;

}  // end of function ddw_wcbr_plugin_links


add_action( 'load-toplevel_page_woocommerce', 'ddw_wcbr_woocommerce_help_tab', 5 );
/**
 * Create and display plugin help tab.
 *
 * @since 2.2
 *
 * @global mixed $wcbr_woocommerce_screen
 */
function ddw_wcbr_woocommerce_help_tab() {

	global $wcbr_woocommerce_screen;

	$wcbr_woocommerce_screen = get_current_screen();

	/** Display help tabs only for WordPress 3.3 or higher */
	if( ! class_exists( 'WP_Screen' ) || ! $wcbr_woocommerce_screen )
		return;

	/** Add the help tab */
	$wcbr_woocommerce_screen->add_help_tab( array(
		'id'       => 'wcbr-woocommerce-help',
		'title'    => __( 'WooCommerce German (de_DE)', 'woocommerce-pt_BR' ),
		'callback' => 'ddw_wcbr_woocommerce_help_content',
	) );

}  // end of function ddw_wcbr_woocommerce_help_tab


/**
 * Create and display plugin help tab content.
 *
 * @since 2.2
 *
 * @global mixed $wcbr_woocommerce_screen, $pagenow
 */
function ddw_wcbr_woocommerce_help_content() {

	echo '<h3>' . __( 'Plugin', 'woocommerce-pt_BR' ) . ': ' . __( 'WooCommerce German (de_DE)', 'woocommerce-pt_BR' ) . '</h3>' .		
		'<ul>';

		/** FAQ/Legal info for German users */
		if ( wcbr_IS_GERMAN ) {

			$wcbr_legal_style = 'style="color: #cc0000;"';

			echo '<li ' . $wcbr_legal_style . '"><em><strong>Haftungsausschluss:</strong> Durch den Einsatz dieses Plugins und der damit angebotenen Sprachdateien entstehen KEINE Garantien für eine korrekte Funktionsweise oder etwaige Verpflichtungen durch den Übersetzer bzw. Plugin-Anbieter! — Alle Angaben ohne Gewähr. Änderungen und Irrtümer ausdrücklich vorbehalten. Verwendung des Plugins inkl. Sprachdateien geschieht ausschliesslich auf eigene Verantwortung!</em></li>' .
				'<li><strong ' . $wcbr_legal_style . '><em>Hinweis 1:</em></strong> Dieses Plugin ist ein reines Sprach-/ Übersetzungs-Plugin, es hat nichts mit "Rechtssicherheit" zu tun. Für alle rechtlichen Fragen ist der Shop-Betreiber zuständig, nicht die "Sprachdatei"!</li>' .
				'<li><strong ' . $wcbr_legal_style . '><em>Hinweis 2:</em></strong> Eine RechtsBERATUNG zu diesem Themenkomplex kann NUR durch einen ANWALT erfolgen (am besten auf Online-Recht spezilisierte Anwälte!). Bitte auch Infos in den einschlägigen Blogs für Shopbetreiber, der (Fach-) Presse sowie von den Industrie- und Handelskammern beachten. -- Ich als Übersetzer und Plugin-Entwickler kann via Sprachdatei KEINE "Rechtssicherheit" garantieren, dies können nur Shop-Betreiber selbst, mit anwaltlicher Unterstützung!</li>' .
				'<li><strong ' . $wcbr_legal_style . '><em>Hinweis 3:</em></strong> JA, die sogenannte "Button-Lösung" wird seit Version 2.1 dieses Plugins und Sprachdatei-Version 1.5.5 (aka WooCommerce 1.5.5+) unterstützt. &mdash; Weitere Informationen bei den <a href="' . esc_url_raw( WCBR_URL_WPORG_FAQ ) . '" target="_new" title="Häufige Fragen (FAQ)"><em>Häufigen Fragen (FAQ)</em></a></li>';

		}  // end if isGerman check

		echo '<li><em>' . __( 'Other, recommended WooCommerce plugins', 'woocommerce-pt_BR' ) . '</em>:';

			/** Optional: recommended plugins */
			if ( wcbr_IS_GERMAN && ! defined( 'WCABA_PLUGIN_BASEDIR' ) ) {

				echo '<br />&raquo; <a href="http://wordpress.org/extend/plugins/woocommerce-admin-bar-addition/" target="_new" title="WooCommerce Admin Bar Addition">WooCommerce Admin Bar Addition</a> &mdash; Dieses Plugin fügt der WordPress Wergzeugleiste bzw. Adminbar nützliche Administratorenlinks und Ressourcen für das WooCommerce Shop-Plugin hinzu.';

			}  // end-if plugin check

			if ( wcbr_IS_GERMAN && ! class_exists( 'WooCommerce_Delivery_Notes' ) ) {

				echo '<br />&raquo; <a href="http://wordpress.org/extend/plugins/woocommerce-delivery-notes/" target="_new" title="WooCommerce Print Invoices & Delivery Notes">WooCommerce Print Invoices & Delivery Notes</a> &mdash; Dieses Plugin stellt einfache Rechnungen und Lieferscheine für das WooCommerce Shop Plugin bereit. Es können dabei auch Firmen-/ Shop-Infos ebenso wie persönliche Anmerkungen oder Bedingungen/ Widerrufsbelehrungen zu den Druckseiten hinzugefügt werden.';

			}  // end-if plugin check

		echo '<br />&raquo; <a href="http://ddwb.me/wccc" target="_new" title="' . __( 'More premium plugins/extensions at CodeCanyon Marketplace', 'woocommerce-pt_BR' ) . ' &hellip;">' . __( 'More premium plugins/extensions at CodeCanyon Marketplace', 'woocommerce-pt_BR' ) . ' &hellip;</a>' .
		'<br />&raquo; <a href="http://wordpress.org/extend/plugins/search.php?q=woocommerce" target="_new" title="' . __( 'More free plugins/extensions at WordPress.org', 'woocommerce-pt_BR' ) . ' &hellip;">' . __( 'More free plugins/extensions at WordPress.org', 'woocommerce-pt_BR' ) . ' &hellip;</a></li>' .
		'</ul>' .
		'<p><strong>' . __( 'Important plugin links:', 'woocommerce-pt_BR' ) . '</strong>' . 
		'<br /><a href="' . esc_url_raw( WCBR_URL_PLUGIN ) . '" target="_new" title="' . __( 'Plugin Website', 'woocommerce-pt_BR' ) . '">' . __( 'Plugin Website', 'woocommerce-pt_BR' ) . '</a> | <a href="' . esc_url_raw( WCBR_URL_WPORG_FAQ ) . '" target="_new" title="' . __( 'FAQ', 'woocommerce-pt_BR' ) . '">' . __( 'FAQ', 'woocommerce-pt_BR' ) . '</a> | <a href="' . esc_url_raw( WCBR_URL_WPORG_FORUM ) . '" target="_new" title="' . __( 'Support', 'woocommerce-pt_BR' ) . '">' . __( 'Support', 'woocommerce-pt_BR' ) . '</a> | <a href="' . esc_url_raw( WCBR_URL_TRANSLATE ) . '" target="_new" title="' . __( 'Translations', 'woocommerce-pt_BR' ) . '">' . __( 'Translations', 'woocommerce-pt_BR' ) . '</a> | <a href="' . esc_url_raw( WCBR_URL_DONATE ) . '" target="_new" title="' . __( 'Donate', 'woocommerce-pt_BR' ) . '">' . __( 'Donate', 'woocommerce-pt_BR' ) . '</a></p>';

}  // end of function ddw_wcbr_woocommerce_help_tab
