<?php
/**
 * @package   WooCommerce Brasil (pt_BR)
 * @author    John-Henrique
 * @link      http://johnhenrique.com
 * @copyright Copyright 2012, John-Henrique - Mídia Negócios
 *
 * @credits   Inspired and based on the plugin "WooCommerce (nl)" by Pronamic, NL.
 * @author    Pronamic, NL / Remco Tolsma
 * @link      http://pronamic.eu/
 * @link      http://twitter.com/#!/pronamic
 *
 * Plugin Name: WooCommerce Brasil (pt_BR)
 * Plugin URI: http://woocommerce.com.br/plugin/woocommerce-brasil-traducao
 * Description: Adicionar o idioma Português Brasileiro. Novas atualizações do idioma são disponibilizadas a cada 10 dias. <strong>Adquira o plugin <a href="http://woocommerce.com.br/plugin/pagseguro-plugin-woocommerce/" target="_new">PagSeguro</a>, <a href="http://woocommerce.com.br/plugin/moip-plugin-woocommerce/" target="_new">MoIP</a> e <a href="http://woocommerce.com.br/plugin/correios-plugin-para-woocommerce/" target="_new">Correios</a></strong>
 * Version: 1.0
 * Author: John-Henrique - Mídia Negócios
 * Author URI: http://johnhenrique.com
 * License: GPLv2 or later
 * License URI: http://www.opensource.org/licenses/gpl-license.php
 * Text Domain: woocommerce-br
 * Domain Path: /wcbr-languages/
 */

/**
 * Setting constants
 *
 * @since 1.0
 * @version 1.1
 */
/** Plugin directory */
define( 'WCBR_PLUGIN_DIR', dirname( __FILE__ ) );

/** Set constant path to the Plugin basename (folder) */
define( 'WCBR_PLUGIN_BASEDIR', dirname( plugin_basename( __FILE__ ) ) );


add_action( 'init', 'ddw_wcbr_init' );
/**
 * Load the text domain for translation of the plugin.
 * Load admin helper functions - only within 'wp-admin'.
 * 
 * @since 1.0
 * @version 1.1
 */
function ddw_wcbr_init() {

	/** Load plugin textdomain plus translation files */
	load_plugin_textdomain( 'woocommerce-pt_BR', false, WCBR_PLUGIN_BASEDIR . '/wcbr-languages/' );

	/** If 'wp-admin' include admin helper functions */
	if ( is_admin() ) {
		require_once( WCBR_PLUGIN_DIR . '/includes/wcbr-admin.php' );
	}

	/** Add "Settings Page" link to plugin page - only within 'wp-admin' */
	if ( is_admin() && current_user_can( 'manage_woocommerce' ) ) {
		add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ) , 'ddw_wcbr_settings_page_link' );
	}

}  // end of function ddw_wcbr_init


/**
 * Helper functions for returning other order button strings.
 *
 * @since 2.1
 *
 * @return string text for order button
 */
	/**
	 * Helper function for returning order button string: "Zahlungspflichtig bestellen"
	 *
	 * @since 2.1
	 *
	 * @return order button string 'Zahlungspflichtig bestellen'
	 */
	function __wcbr_order_button_zahlungspflichtig_bestellen() {

		return 'Zahlungspflichtig bestellen';
	}

	/**
	 * Helper function for returning order button string: "Zahlungspflichtigen Vertrag schließen"
	 *
	 * @since 2.1
	 *
	 * @return order button string 'Zahlungspflichtigen Vertrag schließen'
	 */
	function __wcbr_order_button_zahlungspflichtigen_vertrag() {

		return 'Zahlungspflichtigen Vertrag schließen';
	}

	/**
	 * Helper function for returning order button string: "Kaufen"
	 *
	 * @since 2.1
	 *
	 * @return order button string 'Kaufen'
	 */
	function __wcbr_order_button_kaufen() {

		return 'Kaufen';
	}

/** End of order button helper functions */


/**
 * Main plugin class.
 *
 * All code of this main class by Pronamic, NL, for the "WooCommerce (nl)" plugin
 * @author    Pronamic, NL / Remco Tolsma
 * @copyright Pronamic, NL / Remco Tolsma
 * @license   GPLv2
 * @link      http://pronamic.eu/
 * @link      http://twitter.com/#!/pronamic
 *
 * Modifications needed for German plugin by David Decker (deckerweb).
 *
 * @since 1.0
 * @version 1.2
 */
class WooCommerce_pt_BR {

	/**
	 * The current langauge
	 *
	 * @since 1.0
	 *
	 * @var string
	 */
	private static $language;


	/**
	 * Flag for the German langauge
	 * true if current langauge is German, false otherwise
	 *
	 * @since 1.0
	 *
	 * @var boolean
	 */
	private static $_is_brazilian;


	/**
	 * Bootstrap
	 *
	 * @since 1.0
	 */
	public static function bootstrap() {
		add_filter( 'load_textdomain_mofile', array( __CLASS__, 'load_mo_file' ), 10, 2 );
	}


	/**
	 * Check for installed/ used locale and textdomain .mo file
	 * Check for active WPML language code
	 *
	 * @since 1.0
	 *
	 * @param string $moFile
	 * @param string $domain
	 */
	public static function load_mo_file( $moFile, $domain ) {

		/** Check for installed/ used locale in WordPress */
		if ( self::$language == null ) {
			self::$language = get_option( 'WPLANG', WPLANG );
			self::$_is_brazilian = ( self::$language == 'pt_BR' );

			/** Check for active WPML language code ("WPML" plugin) */
			if (defined( 'ICL_LANGUAGE_CODE' ) ) {
				self::$_is_brazilian = ICL_LANGUAGE_CODE == 'br';
			}
		}

		$newMofile = null;

		/** WooCommerce */
		$_is_woocommerce_domain = ( $domain == 'woocommerce' );

		if ( $_is_woocommerce_domain ) {

			$_is_woocommerce = strpos( $moFile, '/woocommerce/' ) !== false;

			if ( $_is_woocommerce ) {

				$version = get_option( 'woocommerce_db_version', null );

				/** Check for custom file in active theme */
				if ( file_exists( get_stylesheet_directory() . '/woocommerce/sprachdatei/woocommerce-pt_BR.mo' ) ) {
					$newMofile = get_stylesheet_directory() . '/woocommerce/sprachdatei/woocommerce-pt_BR.mo';

				/** Check for regular language folder (SIE-Version = Standard) */
				} elseif ( strpos( $moFile, '/woocommerce/languages/woocommerce-' ) !== false ) {
					$newMofile = self::get_mo_file( 'woocommerce', $version, 'sie-version/' );

				/** Check for formal language folder (SIE-Version) */
				} elseif ( strpos( $moFile, '/woocommerce/languages/formal/woocommerce-' ) !== false ) {
					$newMofile = self::get_mo_file( 'woocommerce', $version, 'sie-version/' );

				/** Check for informal language folder (DU-Version) */
				} elseif ( strpos( $moFile, '/woocommerce/languages/informal/woocommerce-' ) !== false ) {
					$newMofile = self::get_mo_file( 'woocommerce', $version, 'du-version/' );
				}

			}  // end-if $_is_woocommerce

		}  // end-if $_is_woocommerce_domain

		if ( is_readable( $newMofile ) ) {
			$moFile = $newMofile;
		}

		return $moFile;

	}  // end of function load_mo_file


	/**
	 * Get the .mo file for the specified domain, version and language
	 *
	 * @since 1.0
	 */
	public static function get_mo_file( $domain, $version, $path = '' ) {

		$dir = dirname( __FILE__ );

		$moFile = $dir . '/languages/' . $domain . '/' . $version . '/' . $path . self::$language . '.mo';

		/** If specific version .mo file is not available point to the current public release (cpr) version */
		if ( !is_readable( $moFile ) ) {
			$moFile = $dir . '/languages/' . $domain . '/cpr/' . $path . self::$language . '.mo';
		}

		return $moFile;

	}  // end of function get_mo_file

}  // end of main class WooCommerce_de_DE


/** Start class */
WooCommerce_pt_BR::bootstrap();
?>